@@ -2,7 +2,14 @@
 from metakernel.tests.utils import get_kernel, get_log_text, EvalKernel
 import os
 import time
+import pytest
 
+try:
+    import ipyparallel
+except ImportError:
+    ipyparallel = None
+
+@pytest.mark.skipif(ipyparallel is None, reason="Requires ipyparallel")
 def test_parallel_magic():
     kernel = get_kernel(EvalKernel)
     # start up an EvalKernel on each node:
